#
# spec file for package python-sas7bdat
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-sas7bdat
Version:        2.2.3
Release:        2.14
Summary:        A sas7bdat file reader for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://bitbucket.org/jaredhobbs/sas7bdat
Source:         https://files.pythonhosted.org/packages/source/s/sas7bdat/sas7bdat-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.8.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-six >= 1.8.0
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
This module will read sas7bdat files using pure Python (2.6+, 3+). No SAS software
required! The module started out as a port of the R script of the same name
found here: <https://github.com/BioStatMatt/sas7bdat> but has since been
completely rewritten.

Also included with this library is a simple command line script,
`sas7bdat_to_csv`, which converts sas7bdat files to csv files. It will also
print out header information and meta data using the `--header` option and it
will batch convert files as well. Use the `--help` option for more information.

%prep
%setup -q -n sas7bdat-%{version}
sed -i 's/\r$//' README.md

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/sas7bdat_to_csv

%{python_expand sed -i "s|^#!%{_bindir}/env python$|#!%__$python|" %{buildroot}%{$python_sitelib}/sas7bdat.py
chmod a+x %{buildroot}%{$python_sitelib}/sas7bdat.py
$python -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}
$python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}
%fdupes %{buildroot}%{$python_sitelib}
}

%post
%python_install_alternative sas7bdat_to_csv

%postun
%python_uninstall_alternative sas7bdat_to_csv

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/sas7bdat_to_csv
%{python_sitelib}/*

%changelog
* Tue May 19 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Tue Jul 23 2019 Todd R <toddrme2178@gmail.com>
- Update to 2.2.3
  * fix: set the success flag to False on exceptions
  * fix: add optional strip_whitespace_from_strings kwarg to disable stripping whitespace from string type data
- Update to 2.2.2
  * Fix for datasets which have unicode headers.
  * note how to install
  * suggest use of 'skip_header'
  * add documentation around getting column information
  * use more descriptive variable name for SAS7BDAT instance in README
* Sat Dec 22 2018 Todd R <toddrme2178@gmail.com>
- Update to 2.2.1
  * note how to install
  * suggest use of 'skip_header'
  * add documentation around getting column information
  * use more descriptive variable name for SAS7BDAT instance in README
  * bump version to fix pypi documentation formatting
  * revert setup.py
  * use long_description_content_type
  * rewrite RDCDecompressor
  * Add the ability to use file handles, in addition to supplying a path. If the file being accessed is not within the file system (for example, if it is compressed into a zip or tar file) it cannot be opened from the supplied path. This change adds the ability to supply a file handle, and for the module to use that, rather than opening the file itself.
  * fix dist
  * add encoding argument to convert_file()
  * add license; update build script
* Sun Jul 29 2018 jengelh@inai.de
- Trim first person reporting from description.
* Thu May 24 2018 toddrme2178@gmail.com
- Add license file
* Wed Aug 16 2017 toddrme2178@gmail.com
- Initial version
